<?php

    /**
     * For full documentation, please visit: http://docs.reduxframework.com/
     * For a more extensive sample-config file, you may look at:
     * https://github.com/reduxframework/redux-framework/blob/master/sample/sample-config.php
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }

    // This is your option name where all the Redux data is stored.
    $opt_name = "woocommerce_attribute_images_options";

    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        'opt_name' => 'woocommerce_attribute_images_options',
        'use_cdn' => TRUE,
        'dev_mode' => FALSE,
        'display_name' => 'WooCommerce Attribute Images',
        'display_version' => '1.1.1',
        'page_title' => 'Woocommerce Attribute Images',
        'update_notice' => TRUE,
        'intro_text' => '',
        'footer_text' => '&copy; '.date('Y').' DB-Dzine',
        'admin_bar' => TRUE,
        'menu_type' => 'submenu',
        'menu_title' => 'Attribute Images',
        'allow_sub_menu' => TRUE,
        'page_parent' => 'woocommerce',
        // 'page_parent_post_type' => 'stores',
        'customizer' => FALSE,
        'default_mark' => '*',
        'hints' => array(
            'icon_position' => 'right',
            'icon_color' => 'lightgray',
            'icon_size' => 'normal',
            'tip_style' => array(
                'color' => 'light',
            ),
            'tip_position' => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect' => array(
                'show' => array(
                    'duration' => '500',
                    'event' => 'mouseover',
                ),
                'hide' => array(
                    'duration' => '500',
                    'event' => 'mouseleave unfocus',
                ),
            ),
        ),
        'output' => TRUE,
        'output_tag' => TRUE,
        'settings_api' => TRUE,
        'cdn_check_time' => '1440',
        'compiler' => TRUE,
        'page_permissions' => 'manage_options',
        'save_defaults' => TRUE,
        'show_import_export' => TRUE,
        'database' => 'options',
        'transient_time' => '3600',
        'network_sites' => TRUE,
    );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */

    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'help-tab',
            'title'   => __('Information', 'woocommerce-attribute-images' ),
            'content' => __('<p>Need support? Please use the comment function on codecanyon.</p>', 'woocommerce-attribute-images' )
        ),
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    // $content = __('<p>This is the sidebar content, HTML is allowed.</p>', 'woocommerce-attribute-images' );
    // Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    Redux::setSection( $opt_name, array(
        'title'  => __('Attribute Images', 'woocommerce-attribute-images' ),
        'id'     => 'general',
        'desc'   => __('Need support? Please use the comment function on codecanyon.', 'woocommerce-attribute-images' ),
        'icon'   => 'el el-home',
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __('General', 'woocommerce-attribute-images' ),
        // 'desc'       => __('', 'woocommerce-attribute-images' ),
        'id'         => 'general-settings',
        'subsection' => true,
        'fields'     => array(
            array(
                'id'       => 'enable',
                'type'     => 'checkbox',
                'title'    => __('Enable', 'woocommerce-attribute-images' ),
                'subtitle' => __('Enable Attribute Images.', 'woocommerce-attribute-images' ),
                'default'  => '1',
            ),
            array(
                'id'       => 'showTooltip',
                'type'     => 'checkbox',
                'title'    => __('Show Tooltip', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'attributeTableEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Additional Information Table', 'woocommerce-attribute-images' ),
                'subtitle' => __('If image is set for an attribute the attribute value will be replaced with the attribute image style.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'variationsEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Variations Select', 'woocommerce-attribute-images' ),
                'subtitle' => __('If image is set for an attribute the variation selector will be replaced with images.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
            array(
                'id'       => 'attributeFilterWidgetEnable',
                'type'     => 'checkbox',
                'title'    => __('Show Attribute images in Attribute Filter Widget', 'woocommerce-attribute-images' ),
                'subtitle' => __('Only works in List Mode. If image is set for an attribute the attribute value will be replaced with the attribute image in the layered navigation widget by attribute.', 'woocommerce-attribute-images' ),
                'default'  => '1',
                'required' => array('enable','equals','1'),
            ),
        )
    ) );

    Redux::setSection( $opt_name, array(
        'title'      => __('Styling', 'woocommerce-attribute-images' ),
        // 'desc'       => __('', 'woocommerce-attribute-images' ),
        'id'         => 'styling-settings',
        'subsection' => true,
        'fields'     => array(
            array(
               'id' => 'attribute-name-styling',
               'type' => 'section',
               'title' => __('Attribute Name Styling', 'woocommerce-attribute-images'),
               'subtitle' => __('Styling settings for the attribute name (e.g. color).', 'woocommerce-attribute-images'),
               'indent' => false 
            ),
            array(
                'id'       => 'attriNamebuteImageSize',
                'type'     => 'text',
                'title'    => __('Attribute Image Size', 'woocommerce-attribute-images'),
                'default'  => 'full',
            ),
            array(
                'id'     =>'attributeNameImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '100',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeNameImageBorderRadius',
                'type'     => 'spinner', 
                'title'    => __('Image Border Radius (%)', 'woocommerce-attribute-images'),
                'default'  => '0',
                'min'      => '0',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
               'id' => 'attribute-value-styling',
               'type' => 'section',
               'title' => __('Attribute Value Styling', 'woocommerce-attribute-images'),
               'subtitle' => __('Styling settings for the attribute value (e.g. erd).', 'woocommerce-attribute-images'),
               'indent' => false 
            ),
            array(
                'id'       => 'attributeImageSize',
                'type'     => 'text',
                'title'    => __('Attribute Image Size', 'woocommerce-attribute-images'),
                'default'  => 'thumbnail',
            ),
            array(
                'id'     =>'attributeImageWidth',
                'type'     => 'spinner', 
                'title'    => __('Image Width (px)', 'woocommerce-attribute-images'),
                'default'  => '50',
                'min'      => '1',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeImageBorderRadius',
                'type'     => 'spinner', 
                'title'    => __('Image Border Radius (%)', 'woocommerce-attribute-images'),
                'default'  => '50',
                'min'      => '0',
                'step'     => '1',
                'max'      => '9999999999',
            ),
            array(
                'id'     =>'attributeImageBorderColor',
                'type'  => 'color',
                'title' => __('Image Border Color', 'woocommerce-attribute-images'), 
                'validate' => 'color',
                'default' => '#f7f7f7',
            ),
            array(
                'id'     =>'attributeImageActiveBorderColor',
                'type'  => 'color',
                'title' => __('Image Active Border Color (Variations)', 'woocommerce-attribute-images'), 
                'validate' => 'color',
                'default' => '#FF9800',
            ),
        )
    ) );

    /*
     * <--- END SECTIONS
     */
